===============================
Welcome to Ironic Python Agent!
===============================

Overview
========

Ironic Python Agent (often abbreviated as IPA) is an agent for controlling and
deploying :ironic-doc:`Ironic <>` controlled baremetal nodes. Typically run in
a ramdisk, the agent exposes a REST API for provisioning servers.

Contents
========

.. toctree::
  :maxdepth: 3

  install/index
  admin/index
  contributor/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
